@@ -42,8 +42,9 @@ class ImplicitApiPlugin(BasePlugin):
         self._setup_api_properties()
 
     def _setup_api_properties(self):
-        raise NotImplementedError("Method _setup_api_properties() must be implemented in a "
-                                  "subclass of ImplicitApiPlugin")
+        raise NotImplementedError(
+            "Method _setup_api_properties() must be implemented in a " "subclass of ImplicitApiPlugin"
+        )
 
     def on_before_transform_template(self, template_dict):
         """
@@ -102,10 +103,11 @@ class ImplicitApiPlugin(BasePlugin):
             }
         """
 
-        if not (function.valid() and
-                isinstance(function.properties, dict) and
-                isinstance(function.properties.get("Events"), dict)
-                ):
+        if not (
+            function.valid()
+            and isinstance(function.properties, dict)
+            and isinstance(function.properties.get("Events"), dict)
+        ):
             # Function resource structure is invalid.
             return {}
 
@@ -127,8 +129,9 @@ class ImplicitApiPlugin(BasePlugin):
         :param SamTemplate template: SAM Template where Serverless::Api resources can be found
         :param str condition: optional; this is the condition that is on the function with the API event
         """
-        raise NotImplementedError("Method _setup_api_properties() must be implemented in a "
-                                  "subclass of ImplicitApiPlugin")
+        raise NotImplementedError(
+            "Method _setup_api_properties() must be implemented in a " "subclass of ImplicitApiPlugin"
+        )
 
     def _add_implicit_api_id_if_necessary(self, event_properties):
         """
@@ -138,8 +141,9 @@ class ImplicitApiPlugin(BasePlugin):
 
         :param dict event_properties: Dictionary of event properties
         """
-        raise NotImplementedError("Method _setup_api_properties() must be implemented in a "
-                                  "subclass of ImplicitApiPlugin")
+        raise NotImplementedError(
+            "Method _setup_api_properties() must be implemented in a " "subclass of ImplicitApiPlugin"
+        )
 
     def _add_api_to_swagger(self, event_id, event_properties, template):
         """
@@ -156,15 +160,18 @@ class ImplicitApiPlugin(BasePlugin):
 
         # RestApiId is not pointing to a valid  API resource
         if isinstance(api_id, dict) or not template.get(api_id):
-            raise InvalidEventException(event_id,
-                                        "RestApiId must be a valid reference to an 'AWS::Serverless::Api' resource "
-                                        "in same template")
+            raise InvalidEventException(
+                event_id,
+                "RestApiId must be a valid reference to an 'AWS::Serverless::Api' resource " "in same template",
+            )
 
         # Make sure Swagger is valid
         resource = template.get(api_id)
-        if not (resource and
-                isinstance(resource.properties, dict) and
-                self.editor.is_valid(resource.properties.get("DefinitionBody"))):
+        if not (
+            resource
+            and isinstance(resource.properties, dict)
+            and self.editor.is_valid(resource.properties.get("DefinitionBody"))
+        ):
             # This does not have an inline Swagger. Nothing can be done about it.
             return
 
@@ -212,23 +219,28 @@ class ImplicitApiPlugin(BasePlugin):
         # Add a condition to the API resource IFF all of its resource+methods are associated with serverless functions
         # containing conditions.
         implicit_api_conditions = self.api_conditions[self.implicit_api_logical_id]
-        all_resource_method_conditions = set([condition
-                                              for path, method_conditions in implicit_api_conditions.items()
-                                              for method, condition in method_conditions.items()])
+        all_resource_method_conditions = set(
+            [
+                condition
+                for path, method_conditions in implicit_api_conditions.items()
+                for method, condition in method_conditions.items()
+            ]
+        )
         at_least_one_resource_method = len(all_resource_method_conditions) > 0
         all_resource_methods_contain_conditions = None not in all_resource_method_conditions
         if at_least_one_resource_method and all_resource_methods_contain_conditions:
-            implicit_api_resource = template_dict.get('Resources').get(self.implicit_api_logical_id)
+            implicit_api_resource = template_dict.get("Resources").get(self.implicit_api_logical_id)
             if len(all_resource_method_conditions) == 1:
                 condition = all_resource_method_conditions.pop()
-                implicit_api_resource['Condition'] = condition
+                implicit_api_resource["Condition"] = condition
             else:
                 # If multiple functions with multiple different conditions reference the Implicit Api, we need to
                 # aggregate those conditions in order to conditionally create the Implicit Api. See RFC:
                 # https://github.com/awslabs/serverless-application-model/issues/758
-                implicit_api_resource['Condition'] = self.implicit_api_condition
+                implicit_api_resource["Condition"] = self.implicit_api_condition
                 self._add_combined_condition_to_template(
-                    template_dict, self.implicit_api_condition, all_resource_method_conditions)
+                    template_dict, self.implicit_api_condition, all_resource_method_conditions
+                )
 
     def _add_combined_condition_to_template(self, template_dict, condition_name, conditions_to_combine):
         """
@@ -241,9 +253,9 @@ class ImplicitApiPlugin(BasePlugin):
         """
         # defensive precondition check
         if not conditions_to_combine or len(conditions_to_combine) < 2:
-            raise ValueError('conditions_to_combine must have at least 2 conditions')
+            raise ValueError("conditions_to_combine must have at least 2 conditions")
 
-        template_conditions = template_dict.setdefault('Conditions', {})
+        template_conditions = template_dict.setdefault("Conditions", {})
         new_template_conditions = make_combined_condition(sorted(list(conditions_to_combine)), condition_name)
         for name, definition in new_template_conditions.items():
             template_conditions[name] = definition
@@ -261,7 +273,7 @@ class ImplicitApiPlugin(BasePlugin):
         """
 
         for api_id, api in template.iterate(self.api_type):
-            if not api.properties.get('__MANAGE_SWAGGER'):
+            if not api.properties.get("__MANAGE_SWAGGER"):
                 continue
 
             swagger = api.properties.get("DefinitionBody")
@@ -279,7 +291,8 @@ class ImplicitApiPlugin(BasePlugin):
                     else:
                         path_condition_name = self._path_condition_name(api_id, path)
                         self._add_combined_condition_to_template(
-                            template.template_dict, path_condition_name, all_method_conditions)
+                            template.template_dict, path_condition_name, all_method_conditions
+                        )
                         editor.make_path_conditional(path, path_condition_name)
 
             api.properties["DefinitionBody"] = self._get_api_definition_from_editor(editor)  # TODO make static method
@@ -289,8 +302,9 @@ class ImplicitApiPlugin(BasePlugin):
         """
         Required function that returns the api body from the respective editor
         """
-        raise NotImplementedError("Method _setup_api_properties() must be implemented in a "
-                                  "subclass of ImplicitApiPlugin")
+        raise NotImplementedError(
+            "Method _setup_api_properties() must be implemented in a " "subclass of ImplicitApiPlugin"
+        )
 
     def _path_condition_name(self, api_id, path):
         """
@@ -299,8 +313,8 @@ class ImplicitApiPlugin(BasePlugin):
         # only valid characters for CloudFormation logical id are [A-Za-z0-9], but swagger paths can contain
         # slashes and curly braces for templated params, e.g., /foo/{customerId}. So we'll replace
         # non-alphanumeric characters.
-        path_logical_id = path.replace('/', 'SLASH').replace('{', 'OB').replace('}', 'CB')
-        return '{}{}PathCondition'.format(api_id, path_logical_id)
+        path_logical_id = path.replace("/", "SLASH").replace("{", "OB").replace("}", "CB")
+        return "{}{}PathCondition".format(api_id, path_logical_id)
 
     def _maybe_remove_implicit_api(self, template):
         """
@@ -326,5 +340,6 @@ class ImplicitApiPlugin(BasePlugin):
         """
         Helper function implemented by child classes that create a new implicit API resource
         """
-        raise NotImplementedError("Method _setup_api_properties() must be implemented in a "
-                                  "subclass of ImplicitApiPlugin")
+        raise NotImplementedError(
+            "Method _setup_api_properties() must be implemented in a " "subclass of ImplicitApiPlugin"
+        )
