@@ -1,9 +1,14 @@
 import copy
 from samtranslator.model import ResourceTypeResolver, sam_resources
+from collections import OrderedDict
 from samtranslator.translator.verify_logical_id import verify_unique_logical_id
 from samtranslator.model.preferences.deployment_preference_collection import DeploymentPreferenceCollection
-from samtranslator.model.exceptions import (InvalidDocumentException, InvalidResourceException,
-                                            DuplicateLogicalIdException, InvalidEventException)
+from samtranslator.model.exceptions import (
+    InvalidDocumentException,
+    InvalidResourceException,
+    DuplicateLogicalIdException,
+    InvalidEventException,
+)
 from samtranslator.intrinsics.resolver import IntrinsicsResolver
 from samtranslator.intrinsics.actions import FindInMapAction
 from samtranslator.intrinsics.resource_refs import SupportedResourceReferences
@@ -20,6 +25,7 @@ from samtranslator.sdk.parameter import SamParameterValues
 class Translator:
     """Translates SAM templates into CloudFormation templates
     """
+
     def __init__(self, managed_policy_map, sam_parser, plugins=None):
         """
         :param dict managed_policy_map: Map of managed policy names to the ARNs
@@ -31,6 +37,36 @@ class Translator:
         self.plugins = plugins
         self.sam_parser = sam_parser
 
+    def _get_function_names(self, resource_dict, intrinsics_resolver):
+        """
+        :param resource_dict: AWS::Serverless::Function resource is provided as input
+        :param intrinsics_resolver: to resolve intrinsics for function_name
+        :return: a dictionary containing api_logical_id as the key and concatenated String of all function_names
+                 associated with this api as the value
+        """
+        if resource_dict.get("Type") and resource_dict.get("Type").strip() == "AWS::Serverless::Function":
+            if resource_dict.get("Properties") and resource_dict.get("Properties").get("Events"):
+                events = list(resource_dict.get("Properties").get("Events").values())
+                for item in events:
+                    # If the function event type is `Api` then gets the function name and
+                    # adds to the function_names dict with key as the api_name and value as the function_name
+                    if item.get("Type") == "Api" and item.get("Properties") and item.get("Properties").get("RestApiId"):
+                        rest_api = item.get("Properties").get("RestApiId")
+                        if type(rest_api) == dict or isinstance(rest_api, OrderedDict):
+                            api_name = item.get("Properties").get("RestApiId").get("Ref")
+                        else:
+                            api_name = item.get("Properties").get("RestApiId")
+                        if api_name:
+                            resource_dict_copy = copy.deepcopy(resource_dict)
+                            function_name = intrinsics_resolver.resolve_parameter_refs(
+                                resource_dict_copy.get("Properties").get("FunctionName")
+                            )
+                            if function_name:
+                                self.function_names[api_name] = str(self.function_names.get(api_name, "")) + str(
+                                    function_name
+                                )
+        return self.function_names
+
     def translate(self, sam_template, parameter_values):
         """Loads the SAM resources from the given SAM manifest, replaces them with their corresponding
         CloudFormation resources, and returns the resulting CloudFormation template.
@@ -46,6 +82,8 @@ class Translator:
         :returns: a copy of the template with SAM resources replaced with the corresponding CloudFormation, which may \
                 be dumped into a valid CloudFormation JSON or YAML template
         """
+        self.function_names = dict()
+        self.redeploy_restapi_parameters = dict()
         sam_parameter_values = SamParameterValues(parameter_values)
         sam_parameter_values.add_default_parameter_values(sam_template)
         sam_parameter_values.add_pseudo_parameter_values()
@@ -53,33 +91,35 @@ class Translator:
         # Create & Install plugins
         sam_plugins = prepare_plugins(self.plugins, parameter_values)
 
-        self.sam_parser.parse(
-            sam_template=sam_template,
-            parameter_values=parameter_values,
-            sam_plugins=sam_plugins
-        )
+        self.sam_parser.parse(sam_template=sam_template, parameter_values=parameter_values, sam_plugins=sam_plugins)
 
         template = copy.deepcopy(sam_template)
         macro_resolver = ResourceTypeResolver(sam_resources)
         intrinsics_resolver = IntrinsicsResolver(parameter_values)
-        mappings_resolver = IntrinsicsResolver(template.get('Mappings', {}),
-                                               {FindInMapAction.intrinsic_name: FindInMapAction()})
+        mappings_resolver = IntrinsicsResolver(
+            template.get("Mappings", {}), {FindInMapAction.intrinsic_name: FindInMapAction()}
+        )
         deployment_preference_collection = DeploymentPreferenceCollection()
         supported_resource_refs = SupportedResourceReferences()
         document_errors = []
         changed_logical_ids = {}
-
         for logical_id, resource_dict in self._get_resources_to_iterate(sam_template, macro_resolver):
             try:
-                macro = macro_resolver\
-                    .resolve_resource_type(resource_dict)\
-                    .from_dict(logical_id, resource_dict, sam_plugins=sam_plugins)
+                macro = macro_resolver.resolve_resource_type(resource_dict).from_dict(
+                    logical_id, resource_dict, sam_plugins=sam_plugins
+                )
 
-                kwargs = macro.resources_to_link(sam_template['Resources'])
-                kwargs['managed_policy_map'] = self.managed_policy_map
-                kwargs['intrinsics_resolver'] = intrinsics_resolver
-                kwargs['mappings_resolver'] = mappings_resolver
-                kwargs['deployment_preference_collection'] = deployment_preference_collection
+                kwargs = macro.resources_to_link(sam_template["Resources"])
+                kwargs["managed_policy_map"] = self.managed_policy_map
+                kwargs["intrinsics_resolver"] = intrinsics_resolver
+                kwargs["mappings_resolver"] = mappings_resolver
+                kwargs["deployment_preference_collection"] = deployment_preference_collection
+                kwargs["conditions"] = template.get("Conditions")
+                # add the value of FunctionName property if the function is referenced with the api resource
+                self.redeploy_restapi_parameters["function_names"] = self._get_function_names(
+                    resource_dict, intrinsics_resolver
+                )
+                kwargs["redeploy_restapi_parameters"] = self.redeploy_restapi_parameters
                 translated = macro.to_cloudformation(**kwargs)
 
                 supported_resource_refs = macro.get_resource_references(translated, supported_resource_refs)
@@ -88,24 +128,25 @@ class Translator:
                 if logical_id != macro.logical_id:
                     changed_logical_ids[logical_id] = macro.logical_id
 
-                del template['Resources'][logical_id]
+                del template["Resources"][logical_id]
                 for resource in translated:
-                    if verify_unique_logical_id(resource, sam_template['Resources']):
-                        template['Resources'].update(resource.to_dict())
+                    if verify_unique_logical_id(resource, sam_template["Resources"]):
+                        template["Resources"].update(resource.to_dict())
                     else:
-                        document_errors.append(DuplicateLogicalIdException(
-                            logical_id, resource.logical_id, resource.resource_type))
+                        document_errors.append(
+                            DuplicateLogicalIdException(logical_id, resource.logical_id, resource.resource_type)
+                        )
             except (InvalidResourceException, InvalidEventException) as e:
                 document_errors.append(e)
 
         if deployment_preference_collection.any_enabled():
-            template['Resources'].update(deployment_preference_collection.codedeploy_application.to_dict())
+            template["Resources"].update(deployment_preference_collection.codedeploy_application.to_dict())
 
             if not deployment_preference_collection.can_skip_service_role():
-                template['Resources'].update(deployment_preference_collection.codedeploy_iam_role.to_dict())
+                template["Resources"].update(deployment_preference_collection.codedeploy_iam_role.to_dict())
 
             for logical_id in deployment_preference_collection.enabled_logical_ids():
-                template['Resources'].update(deployment_preference_collection.deployment_group(logical_id).to_dict())
+                template["Resources"].update(deployment_preference_collection.deployment_group(logical_id).to_dict())
 
         # Run the after-transform plugin target
         try:
@@ -114,8 +155,8 @@ class Translator:
             document_errors.append(e)
 
         # Cleanup
-        if 'Transform' in template:
-            del template['Transform']
+        if "Transform" in template:
+            del template["Transform"]
 
         if len(document_errors) == 0:
             template = intrinsics_resolver.resolve_sam_resource_id_refs(template, changed_logical_ids)
@@ -195,12 +236,14 @@ def prepare_plugins(plugins, parameters={}):
 def make_implicit_rest_api_plugin():
     # This is necessary to prevent a circular dependency on imports when loading package
     from samtranslator.plugins.api.implicit_rest_api_plugin import ImplicitRestApiPlugin
+
     return ImplicitRestApiPlugin()
 
 
 def make_implicit_http_api_plugin():
     # This is necessary to prevent a circular dependency on imports when loading package
     from samtranslator.plugins.api.implicit_http_api_plugin import ImplicitHttpApiPlugin
+
     return ImplicitHttpApiPlugin()
 
 
